mpd-sima

## Name

mpd-sima — mpd-sima will try to maintain some titles ahead in the queue following different policies.

## Synopsis

`mpd-sima` [`--daemon`] [`--config=``conf_file`] [`--var-dir=``var_directory`] [`--pid=``pid_file`] [`--log=``log_file`] [`--log-level=``log_level`] [`--host=``mpd_host`] [`--mpd_port=``mpd_port`]

`mpd-sima` --create-db [`--var-dir=``var_directory`]

`mpd-sima` --generate-config [`…`]

`mpd-sima` { { `-h` | `--help` } `--version` }

## DESCRIPTION

This manual page documents briefly the mpd-sima commands.

At start up default configuration is first overridden by user configuration in mpd_sima.cfg (see the section called “FILES”) and finally command lines options are honored. For instance you can override default MPD_HOST set in defaults (localhost) or in your configuration file with -S my_mpd_server option. For default configuration see the section called “CONFIGURATION”. See also environment variables special case for MPD host and port in the section called “ENVIRONMENT”.

## EXAMPLE

### Launch as a system service (dæmon).

Here follows an example on how to launch mpd-sima as a service on your system, not attach to regular user configuration/database.

mpd-sima --daemon --conf=/etc/mpd_sima.cfg --var-dir=/var/cache/mpd-sima/ --pid=/run/mpd-sima.pid --log=/var/log/mpd-sima.log

### Launch in user land

Launching mpd-sima from/whithin your user account is easy, you can simply call mpd-sima from your shell or one of the following command:

Background execution (dæmonise), log in the specified file, save pid:

mpd-sima --daemon --pid=$HOME/var/run/mpd-sima.pid --log=$HOME/var/log/mpd-sima.log

Foreground execution, connect my.mpd.server.org, log to std(out|err):

mpd-sima --host=my.mpd.server.org

## OPTIONS

The program follows the usual GNU command line syntax, with long options starting with two dashes (`-'). A summary of options is included below.

`-h`, `--help`

  Print help and exit.

`--version`

  Print version and exit.

`--daemon`

  Start as a daemon. Log redirected to /dev/null, usually setting `--log` and `--pid` options in daemon mode are a good idea to monitor/stop the process.

`-p `pid_file``, `--pid=`pid_file``

  Use the specific file `pid_file` to store pid to.
  Default is not to store pid info.

`-l `log_file``, `--log=`log_file``

  Use the specific file `log_file` to log messages to.
  Default is to log to stdout/stderr.

`-v `log_level``, `--log-level=`log_level``

  Verbosity in [debug,info,warning,error].
  Default is to log info messages.

`-c `conf_file``, `--config=`conf_file``

  Use the specific file `conf_file` to set up configuration instead of looking for the default user configuration file.
  Default is to look for `$XDG_CONFIG_HOME/mpd_sima/mpd_sima.cfg`.
  CLI option overrides any equivalent mentioned in configuration file, ie. launching mpd-sima with '`--port`' CLI option will ignore port setting in configuration file.
  For more details on configuration file cf. mpd_sima.cfg(5), see also the section called “FILES”.

`--var-dir=`var_directory``

  Use the specific path `var_directory` to look for (or create) var files (ie. database) instead of looking at the default user data location.
  Default is to look in `$XDG_DATA_HOME/mpd_sima/`. Concerning `$XDG_DATA_HOME` see also the section called “FILES”

`--generate-config`

  Generate a sample configuration file according to the current configuration. You can put other options with this one to get them in the generated configuration.

`--create-db`

  Create the database and exit. Uses folder specified with `--var-dir` or default directory.
  Default is to use `$XDG_DATA_HOME/mpd_sima/`. Concerning `$XDG_DATA_HOME` see also the section called “FILES”

`-S `mpd_host``, `--host=`mpd_host``

  Use the specific host `mpd_host` as MPD server.
  `mpd_host` can be an IP or a fully qualified domain name as long as your system can resolve it. This overrides `MPD_HOST` environment variable.
  Default is localhost.

  See also the section called “ENVIRONMENT”.

`-P `mpd_port``, `--port=`mpd_port``

  Use the specific port number `mpd_port` on MPD server. This overrides `MPD_PORT` environment variable.
  Default is 6600.

  See also the section called “ENVIRONMENT”

## FILES

`${XDG_CONFIG_HOME}/mpd_sima/mpd_sima.cfg`

  Configuration file.

`${XDG_DATA_HOME}/mpd_sima/sima.db`

  SQLite DB file.

`${XDG_DATA_HOME}/mpd_sima/WEB_SERVICE/`

  Persistent http cache.

Usually `XDG_DATA_HOME` is set to `${HOME}/.local/share` and `XDG_CONFIG_HOME` to `${HOME}/.config`.
You may override them using command line option `--var-dir` and `--config` (cf. mpd-sima(1))

## ENVIRONMENT

`MPD_HOST`, `MPD_PORT`

  mpd-sima will look for `MPD_HOST` and `MPD_PORT` to override built-in configuration (set to "localhost:6600").

  mpd-sima expects `MPD_HOST` syntax as documented in mpc manual, cf. mpc(1).
  To use a password, provide a value of the form "password@host".

`HTTP_PROXY`, `HTTPS_PROXY`

  mpd-sima honors `HTTP_PROXY` environment variables.

## CONFIGURATION

`mpd_sima.cfg`

  `mpd_sima.cfg` is read if present. Otherwise built-in defaults are used. An example should be provided in the tarball within `doc/examples/`. On Debian system please look in `/usr/share/doc/mpd-sima`.

DEFAULTS

  Default is to look for MPD server at localhost:6600 (or MPD_HOST/MPD_PORT env. var. if set).

  The get the defaults as detected by mpd-sima on your system you can run mpd-sima to print the config:

  mpd-sima --generate-config

For details about mpd_sima.cfg refer to the manual mpd_sima.cfg(5)

## FEEDBACK/BUGS

The maintainer would be more than happy to ear from you, don't hesitate to send feedback, http://kaliko.me/id/.

XMPP users are welcome to join the dedicated chat room at kaliko.me@conf.azylum.org.

## SEE ALSO

mpc(1), mpd(1)

`/usr/share/doc/mpd-sima/`